<?php
require_once 'config.php';
require_once 'vendor/autoload.php';

use Minishlink\WebPush\WebPush;
use Minishlink\WebPush\Subscription;

session_start();

$req_method = strtoupper($_SERVER['REQUEST_METHOD']);

const VAPID_SUBJECT = 'http://localhost:8080';

if ($req_method === 'POST') {
    $message = file_get_contents('php://input');

    // push通知認証用のデータ
    $subscription = Subscription::create([
        'endpoint' => $_SESSION['endpoint'],
        'publicKey' => $_SESSION['userPublickKey'],
        'authToken' => $_SESSION['userAuthToken'],
    ]);

    // ブラウザに認証させる
    $auth = [
        'VAPID' => [
            'subject' => VAPID_SUBJECT,
            'publicKey' => PUBLIC_KEY,
            'privateKey' => PRIVATE_KEY,
        ]
    ];

    $webPush = new WebPush($auth);

    $report = $webPush->sendOneNotification(
        $subscription,
        $message
    );

    if ($report->isSuccess()) {
        echo '送信成功！';
    } else {
        echo '送信失敗...';
    }
    
    die();
}
?>
<!DOCTYPE html>
<html lang="jp">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>SendPush</title>
    <script>
        window.URL = '<?php echo $_SERVER['PHP_SELF']; ?>';
    </script>
</head>

<body>
    <h1>メッセージ送信</h1>
    <form id="messageForm">
        <label for="message">メッセージ</label>
        <input type="text" id="message" name="message">
        <button>送信</button>
    </form>
    <h2>送信済みメッセージ</h2>
    <ul id="messages">
    </ul>
    <script src="SendPush.js"></script>
</body>

</html>